/*
 * Copyright 2010 Inalogic® Inc.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License, as
 * published by the  Free Software Foundation; either version 2.1 or 3.0
 * of the License.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the applicable version of the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of both the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>
 *
 * Authored by: Jay Taoko <jaytaoko@inalogic.com>
 *
 */


#include "NuxCore.h"
#include "NUniqueIndex.h"

namespace nux
{

  NUX_IMPLEMENT_GLOBAL_OBJECT (UniqueIndex);

  NCriticalSection UniqueIndex::m_CriticalSection;

  void UniqueIndex::Constructor()
  {
  }

  void UniqueIndex::Destructor()
  {
  }

  unsigned long long UniqueIndex::GetUniqueIndex()
  {
    NScopeLock Scope (&m_CriticalSection);
    m_UniqueIndex.Increment();
    return m_UniqueIndex.GetValue();
  }

}

